summaryrefslogtreecommitdiffstats
path: root/queue.h
diff options
context:
space:
mode:
authorRainer Gerhards <rgerhards@adiscon.com>2008-01-27 10:33:03 +0000
committerRainer Gerhards <rgerhards@adiscon.com>2008-01-27 10:33:03 +0000
commit0c6c9dfe8a6da1553e39167600222cb6ab7e4b8b (patch)
treec81037534b101008d3e8355258c66dea8071291d /queue.h
parent439f19ad38f5dcc3282d450a2a15cea3238fc754 (diff)
downloadrsyslog-0c6c9dfe8a6da1553e39167600222cb6ab7e4b8b.tar.gz
rsyslog-0c6c9dfe8a6da1553e39167600222cb6ab7e4b8b.tar.xz
rsyslog-0c6c9dfe8a6da1553e39167600222cb6ab7e4b8b.zip
fixed the situation where message processing could be stalled for some
period after DA mode turn off
Diffstat (limited to 'queue.h')
-rw-r--r--queue.h6
1 files changed, 4 insertions, 2 deletions
diff --git a/queue.h b/queue.h
index e51e670a..c9abced0 100644
--- a/queue.h
+++ b/queue.h
@@ -95,8 +95,10 @@ typedef struct queue_s {
pthread_cond_t *condSignalOnEmpty;/* caller-provided condition to be signalled when queue is empty (DA mode!) */
pthread_mutex_t *mutSignalOnEmpty; /* and its associated mutex */
pthread_cond_t *condSignalOnEmpty2;/* another condition to be signalled on empty */
- int bSignalOnEmpty; /* signal caller when queue is empty via xxxSignalOnEmpty cond/mut,
- 0 = do not, 1 = signal only condSignalOnEmpty, 2 = signal both condSig..*/
+ //int bSignalOnEmpty; /* signal caller when queue is empty via xxxSignalOnEmpty cond/mut,
+ // 0 = do not, 1 = signal only condSignalOnEmpty, 2 = signal both condSig..*/ // TODO: no longer needed?
+
+ int bChildIsDone; /* set to 1 when the child DA queue has finished processing, 0 otherwise */
int bThrdStateChanged; /* at least one thread state has changed if 1 */
/* end sync variables */
/* the following variables are always present, because they